@@ -13,5 +13,5 @@ from dataclasses import dataclass
 class DefocusSettings:
     rtsp_url: str
     freq_diff_threshold: float
-    created_at: float
-    updated_at: float
+    created_at: float | None = None
+    updated_at: float | None = None
